แพ็คเกจนี้เป็นแพ็คเกจ python ที่โชว์ข้อมูลเกี่ยวกับ buider
==========================================================

PyPi: https://pypi.org/project/MynameisBuilder/

สวัสดีจ้าาาา แพ็คนี้คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับ Builder
ท่านสามารถดูข้อมูลได้ทางลิ้งได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install MynameisBuilder

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from MynameisBuilder import Build

   build = Builder() #ประการศชื่อ class
   build.show_name() #โชว์ชื่อ
   build.page() #โชว์ลิ้งเพจ
   build.show_youtube() #โชว์ลิ้งยูทูป
   build.about() #เกี่ยวกับ บิ้ว
   build.show_art()#โชวศิลปะ

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer

YouTube: https://www.youtube.com/UncleEngineer
